pub fn upgrade<F, Fut>(handler: F) -> ReplyDataExpand description
Return this from a route handler to turn the response into a WebSocket
upgrade. handler runs on the upgraded connection after the handshake.
See the module docs.
pub fn upgrade<F, Fut>(handler: F) -> ReplyDataReturn this from a route handler to turn the response into a WebSocket
upgrade. handler runs on the upgraded connection after the handshake.
See the module docs.